# Commercial Licensing

neroued_3mf is dual-licensed:

1. **AGPL-3.0** — Free for open-source projects that comply with the AGPL-3.0 terms
   (all derivative works and networked services must also be open-sourced under AGPL-3.0).

2. **Commercial License** — For proprietary / closed-source usage that cannot comply with
   AGPL-3.0, a separate commercial license is available.

## When do I need a commercial license?

- You are integrating neroued_3mf into a closed-source product.
- You are offering a service that uses neroued_3mf and do not wish to release your service
  code under AGPL-3.0.
- Your organization's legal policy prohibits AGPL-3.0 dependencies.

## Contact

For commercial licensing inquiries, please contact the author.
